{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2015-2018 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{% extends config.THEME_BASE_TEMPLATE %}

{% block page_body %}
<div class="container error-page">
<div class="row">
  <div class="col-sm-12">
  {% block message %}{% endblock message %}
  </div>
</div>
</div>
{% endblock %}
