/*
 * This file is part of Invenio.
 * Copyright (C) 2016-2018 CERN.
 *
 * Invenio is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */
// eslint-disable-next-line no-unused-vars
import jquery from "jquery";
// eslint-disable-next-line no-unused-vars
import bootstrap from "bootstrap-sass/assets/javascripts/bootstrap";
// eslint-disable-next-line no-unused-vars
import moment from "moment";
// eslint-disable-next-line no-unused-vars
import select2 from "select2";
// eslint-disable-next-line no-unused-vars
import AdminLTE from "admin-lte/dist/js/adminlte";

// Expose select2 and moment globally
window.select2 = select2;
window.moment = moment;
