{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2015-2018 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
  <div class="ui divider fitted hidden"></div>
#}

<footer id="footer">
  <div class="ui container">
    <div class="ui divider"></div>
  </div>
  <div class="ui grid container">
    <div class="eight wide column">
      {% trans link="http://inveniosoftware.org" %}Powered by
        <a href="{{ link }}">Invenio</a>{% endtrans %}
    </div>
    <div class="eight wide column right aligned">
    {%- if config.I18N_LANGUAGES %}
      {% from "invenio_i18n/macros/language_selector.html" import language_selector_dropdown %}
      {{ language_selector_dropdown() }}
    {%- endif %}
    </div>
  </div>
</footer>
